==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyRuleConditionsPeople.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Identifies Users and Groups that are used together
 */
@ApiModel(description = "Identifies Users and Groups that are used together")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyRuleConditionsPeople.JSON_PROPERTY_USERS })
@JsonTypeName("AuthenticatorEnrollmentPolicyRuleConditions_people")
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class AuthenticatorEnrollmentPolicyRuleConditionsPeople implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_USERS = "users";
    private AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers users;

    public AuthenticatorEnrollmentPolicyRuleConditionsPeople() {
    }

    public AuthenticatorEnrollmentPolicyRuleConditionsPeople users(
            AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers users) {

        this.users = users;
        return this;
    }

    /**
     * Get users
     *
     * @return users
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers getUsers() {
        return users;
    }

    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUsers(AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers users) {
        this.users = users;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyRuleConditionsPeople authenticatorEnrollmentPolicyRuleConditionsPeople = (AuthenticatorEnrollmentPolicyRuleConditionsPeople) o;
        return Objects.equals(this.users, authenticatorEnrollmentPolicyRuleConditionsPeople.users);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(users);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyRuleConditionsPeople {\n");
        sb.append("    users: ").append(toIndentedString(users)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/AuthenticatorEnrollmentPolicyRuleConditionsPeople.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Identifies Users and Groups that are used together
 */
@ApiModel(description = "Identifies Users and Groups that are used together")
@JsonPropertyOrder({ AuthenticatorEnrollmentPolicyRuleConditionsPeople.JSON_PROPERTY_USERS })
@JsonTypeName("AuthenticatorEnrollmentPolicyRuleConditions_people")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class AuthenticatorEnrollmentPolicyRuleConditionsPeople implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_USERS = "users";
    private AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers users;

    public AuthenticatorEnrollmentPolicyRuleConditionsPeople() {
    }

    public AuthenticatorEnrollmentPolicyRuleConditionsPeople users(
            AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers users) {

        this.users = users;
        return this;
    }

    /**
     * Get users
     *
     * @return users
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers getUsers() {
        return users;
    }

    @JsonProperty(JSON_PROPERTY_USERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUsers(AuthenticatorEnrollmentPolicyRuleConditionsPeopleUsers users) {
        this.users = users;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        AuthenticatorEnrollmentPolicyRuleConditionsPeople authenticatorEnrollmentPolicyRuleConditionsPeople = (AuthenticatorEnrollmentPolicyRuleConditionsPeople) o;
        return Objects.equals(this.users, authenticatorEnrollmentPolicyRuleConditionsPeople.users);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(users);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class AuthenticatorEnrollmentPolicyRuleConditionsPeople {\n");
        sb.append("    users: ").append(toIndentedString(users)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
